@@ -9,7 +9,7 @@ BEGIN { require 5.006; }
 BEGIN { ${^WARNING_BITS} = ""; }
 # Don't "use strict" here, to avoid dependencies.
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 # Don't use Exporter here, to avoid dependencies.
 our @EXPORT_OK = qw(
@@ -23,7 +23,7 @@ our @EXPORT_OK = qw(
 my %export_ok = map { ($_ => undef) } @EXPORT_OK;
 sub import {
     my $me = shift;
-    my $callpkg = caller(0);
+    my $callpkg = caller;
     my $errs = "";
     foreach(@_) {
         if(exists $export_ok{$_}) {
@@ -39,8 +39,8 @@ sub import {
         }
     }
     if($errs ne "") {
-        die "${errs}Can't continue after import errors ".
-            "at @{[(caller(0))[1]]} line @{[(caller(0))[2]]}.\n";
+        die sprintf "%sCan't continue after import errors at %s line %u.\n",
+            $errs, (caller)[1,2];
     }
 }
 
@@ -51,19 +51,19 @@ sub _is_string($) {
     return defined($arg) && ref(\$arg) eq "SCALAR";
 }
 
-our $module_name_rx = qr/[A-Z_a-z][0-9A-Z_a-z]*(?:::[0-9A-Z_a-z]+)*/;
+our $module_name_rx = qr{[A-Z_a-z][0-9A-Z_a-z]*(?:::[0-9A-Z_a-z]+)*};
 
 my $qual_module_spec_rx =
-    qr#(?:/|::)[A-Z_a-z][0-9A-Z_a-z]*(?:(?:/|::)[0-9A-Z_a-z]+)*#;
+    qr{(?:/|::)[A-Z_a-z][0-9A-Z_a-z]*(?:(?:/|::)[0-9A-Z_a-z]+)*};
 
 my $unqual_top_module_spec_rx =
-    qr#[A-Z_a-z][0-9A-Z_a-z]*(?:(?:/|::)[0-9A-Z_a-z]+)*#;
+    qr{[A-Z_a-z][0-9A-Z_a-z]*(?:(?:/|::)[0-9A-Z_a-z]+)*};
 
-our $top_module_spec_rx = qr/$qual_module_spec_rx|$unqual_top_module_spec_rx/o;
+our $top_module_spec_rx = qr{$qual_module_spec_rx|$unqual_top_module_spec_rx};
 
-my $unqual_sub_module_spec_rx = qr#[0-9A-Z_a-z]+(?:(?:/|::)[0-9A-Z_a-z]+)*#;
+my $unqual_sub_module_spec_rx = qr{[0-9A-Z_a-z]+(?:(?:/|::)[0-9A-Z_a-z]+)*};
 
-our $sub_module_spec_rx = qr/$qual_module_spec_rx|$unqual_sub_module_spec_rx/o;
+our $sub_module_spec_rx = qr{$qual_module_spec_rx|$unqual_sub_module_spec_rx};
 
 sub is_module_name($) { _is_string($_[0]) && $_[0] =~ /\A$module_name_rx\z/o }
 
@@ -79,7 +79,7 @@ sub check_module_name($) {
 sub module_notional_filename($) {
     &check_module_name;
     my($name) = @_;
-    $name =~ s!::!/!g;
+    $name =~ s{::}{/}g;
     return $name.".pm";
 }
 
@@ -148,9 +148,10 @@ sub use_package_optimistically($;$) {
 
 sub is_module_spec($$) {
     my($prefix, $spec) = @_;
-    return _is_string($spec) &&
-        $spec =~ ($prefix ? qr/\A$sub_module_spec_rx\z/o :
-                            qr/\A$top_module_spec_rx\z/o);
+    return _is_string($spec) && (
+        $prefix ? $spec =~ /\A$sub_module_spec_rx\z/o
+                : $spec =~ /\A$top_module_spec_rx\z/o
+    );
 }
 
 *is_valid_module_spec = \&is_module_spec;
@@ -166,12 +167,12 @@ sub compose_module_name($$) {
     my($prefix, $spec) = @_;
     check_module_name($prefix) if defined $prefix;
     &check_module_spec;
-    if($spec =~ s#\A(?:/|::)##) {
+    if($spec =~ s{\A(?:/|::)}{}) {
         # OK
     } else {
         $spec = $prefix."::".$spec if defined $prefix;
     }
-    $spec =~ s#/#::#g;
+    $spec =~ s{/}{::}g;
     return $spec;
 }
 
